-- CAMBIOS A BASE DE DATOS POS
ALTER TABLE `tbl_retiros` ADD COLUMN `consecutivo` INT(11) NULL AFTER `fecha_retiro`;


UPDATE tbl_usuarios
SET permisos = '[MN_POS_MODIFICARVENTA|\n[MN_POS_CORTECAJA|\n[MN_POS_RETIROCAJA|\n[MN_POS_APLICADESCUENTO|\n[MN_POS_APLICADEVOLUCION|'
WHERE id_user = 1;

UPDATE cat_configuracion
SET url_sync_usuarios = 'http://hks.softnet.com.mx/ERP/sync_usuarios.php';



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_insertarRetiro`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_insertarRetiro`(
	in_inicial DECIMAL(15,2),
	in_retiro DECIMAL(15,2),
	in_id_user_caja INT,
	in_id_user_retiro INT
)
    COMMENT 'Agregar registro de retiro de caja'
BEGIN
	START TRANSACTION;
	SET @consecutivo = (
		SELECT COALESCE(MAX(consecutivo), 0) + 1
		FROM tbl_retiros
		WHERE CAST(fecha_retiro AS DATE) = CURDATE()
	);
	INSERT INTO tbl_retiros
	SET fecha_retiro = NOW(),
		consecutivo = @consecutivo,
		efectivo_inicial = in_inicial,
		retiro = in_retiro,
		efectivo_final = efectivo_inicial - retiro,
		id_usuario_caja = in_id_user_caja,
		id_usuario_retiro = in_id_user_retiro;
	
	SET @id = LAST_INSERT_ID();
	COMMIT;
	
	-- Retorna ID del movimiento y # de Referencia
	SELECT  @id AS id_retiro;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_listarPedidos`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_listarPedidos`(
	in_tipo_movimiento INT,
	in_fecha DATE
)
    COMMENT 'Recupera los pedidos que no se han pagado aun'
BEGIN
	CASE in_tipo_movimiento
		WHEN 1 THEN
			-- Listar Pedidos
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				1 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago + 1,'Efectivo','T. Débito','T. Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.pagado <> mov.total
				AND mov.fecha_cancelado IS NULL
			GROUP BY mov.id_movimiento;
		WHEN 2 THEN
			-- Listar Ventas
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				0 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago + 1,'Efectivo','T. Débito','T. Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.pagado = mov.total
				AND mov.fecha = in_fecha
			GROUP BY mov.id_movimiento;
		WHEN 3 THEN
			-- Listar Cancelaciones
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				0 AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago + 1,'Efectivo','T. Débito','T. Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			WHERE mov.fecha_cancelado IS NOT NULL
			GROUP BY mov.id_movimiento;
		WHEN 4 THEN
			-- Listar Todos
			SELECT mov.id_movimiento,
				mov.consecutivo,
				mov.fecha,
				mov.hora,
				CONCAT(IF(ISNULL(mov.fecha_cancelado), '', 'CANCELADO - '), mov.referencia) AS referencia,
				u.nombre AS nombre_vendedor,
				mov.total,
				mov.total - mov.pagado AS saldo,
				IF(ISNULL(mov.consolidado), '', 'OK') AS txt_enviada,
				IF(mov.pagado <> mov.total AND ISNULL(mov.fecha_cancelado), 1, 0) AS activo,
				IF(ISNULL(mov.consolidado), 0, 1) AS enviado,
				mov.pagado,
				GROUP_CONCAT(ELT(mp.id_forma_pago + 1,'Efectivo','T. Débito','T. Crédito')) AS forma_pago,
				IF(mov.factura = 1, 'SI', '') AS factura
			FROM tbl_movimientos AS mov
			JOIN tbl_usuarios AS u
				ON u.id_user = mov.id_usuario_venta
			LEFT OUTER JOIN tbl_movimientos_pagos AS mp
				ON mp.id_movimiento = mov.id_movimiento
			GROUP BY mov.id_movimiento
			; -- HERE mov.pagado <> mov.total;
	END CASE;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateSyncVenta`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateSyncVenta`(
	in_id_venta INT
)
    COMMENT 'Marca la venta como sincronizada'
BEGIN
	UPDATE tbl_movimientos
	SET consolidado = NOW()
	WHERE id_movimiento = in_id_venta;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateUrls`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateUrls`(
	in_url_empresa TEXT,
	in_url_usuarios TEXT,
	in_url_sucursales TEXT,
	in_url_productos TEXT,
	in_url_precios TEXT,
	in_url_existencias TEXT,
	in_url_ventas TEXT
)
    COMMENT 'Guarda la configuracion de Urls para sincronizacion de catalogos'
BEGIN
	UPDATE cat_configuracion
	SET url_sync_empresa = in_url_empresa,
		url_sync_usuarios = in_url_usuarios,
		url_sync_sucursales = in_url_sucursales,
		url_sync_productos = in_url_productos,
		url_sync_precios = in_url_precios,
		url_existencias = in_url_existencias,
		url_sync_ventas = in_url_ventas;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateUsuario`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateUsuario`(
	in_id_user INT,
	in_user_name VARCHAR(20),
	in_user_pass VARCHAR(60),
	in_nombre VARCHAR(100),
	in_permisos TEXT,
	in_activo INT
)
    COMMENT 'Inserta o actualiza un usuario'
BEGIN
    INSERT INTO tbl_usuarios
    SET id_user = in_id_user,
        user_name = in_user_name,
        user_pass = in_user_pass,
        nombre = in_nombre,
        permisos = in_permisos,
        activo = in_activo
    ON DUPLICATE KEY
    UPDATE user_name = in_user_name,
        user_pass = in_user_pass,
        nombre = in_nombre,
        permisos = in_permisos,
        activo = in_activo;
END$$

DELIMITER ;